==> softhsm2_2.0.0.orig.tar.gz: softhsm-2.0.0/src/lib/test/SessionTests.h <==
/*
 * Copyright (c) 2010 .SE (The Internet Infrastructure Foundation)
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
 * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
 * IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
 * IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/*****************************************************************************
 SessionTests.h

 Contains test cases to C_OpenSession, C_CloseSession, C_CloseAllSessions, and
 C_GetSessionInfo
 *****************************************************************************/

#ifndef _SOFTHSM_V2_SESSIONTESTS_H
#define _SOFTHSM_V2_SESSIONTESTS_H

#include <cppunit/extensions/HelperMacros.h>
#include "cryptoki.h"

class SessionTests : public CppUnit::TestFixture
{
	CPPUNIT_TEST_SUITE(SessionTests);
	CPPUNIT_TEST(testOpenSession);
	CPPUNIT_TEST(testCloseSession);
	CPPUNIT_TEST(testCloseAllSessions);
	CPPUNIT_TEST(testGetSessionInfo);
	CPPUNIT_TEST_SUITE_END();

public:
	void testOpenSession();
	void testCloseSession();
	void testCloseAllSessions();
	void testGetSessionInfo();

	void setUp();
	void tearDown();
};

#endif // !_SOFTHSM_V2_SESSIONTESTS_H

==> softhsm2_2.6.1.orig.tar.gz: softhsm2-2.6.1/src/lib/test/SessionTests.h <==
/*
 * Copyright (c) 2010 .SE (The Internet Infrastructure Foundation)
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
 * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
 * IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
 * IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/*****************************************************************************
 SessionTests.h

 Contains test cases to C_OpenSession, C_CloseSession, C_CloseAllSessions, and
 C_GetSessionInfo
 *****************************************************************************/

#ifndef _SOFTHSM_V2_SESSIONTESTS_H
#define _SOFTHSM_V2_SESSIONTESTS_H

#include "TestsNoPINInitBase.h"
#include <cppunit/extensions/HelperMacros.h>

class SessionTests : public TestsNoPINInitBase
{
	CPPUNIT_TEST_SUITE(SessionTests);
	CPPUNIT_TEST(testOpenSession);
	CPPUNIT_TEST(testCloseSession);
	CPPUNIT_TEST(testCloseAllSessions);
	CPPUNIT_TEST(testGetSessionInfo);
	CPPUNIT_TEST_SUITE_END();

public:
	void testOpenSession();
	void testCloseSession();
	void testCloseAllSessions();
	void testGetSessionInfo();
};

#endif // !_SOFTHSM_V2_SESSIONTESTS_H
